@@ -1,10 +1,10 @@
 package Catmandu::Importer::EuropePMC;
 
 use Catmandu::Sane;
-use Moo;
-use LWP::UserAgent;
-use XML::Simple qw(XMLin);
+use XML::LibXML::Simple qw(XMLin);
 use Try::Tiny;
+use Furl;
+use Moo;
 
 with 'Catmandu::Importer';
 
@@ -22,45 +22,36 @@ my %MAP = (references => 'reference',
   citations => 'citation',
   dbCrossReferenceInfo => 'dbCrossReference');
 
-# Returns the raw response object.
 sub _request {
   my ($self, $url) = @_;
 
-  my $ua = LWP::UserAgent->new;
-  $ua->timeout(20);
+  my $ua = Furl->new(timeout => 20);
 
   my $res;
   try {
     $res = $ua->get($url);
     die $res->status_line unless $res->is_success;
 
-    return $res->decoded_content;
+    return $res->content;
   } catch {
     Catmandu::Error->throw("Status code: $res->status_line");
   };
 
 }
 
-# Returns a hash representation of the given XML.
 sub _hashify {
   my ($self, $in) = @_;
 
-  my $xs = XML::Simple->new();
+  my $xs = XML::LibXML::Simple->new();
   my $field = $MAP{$self->module};
-  my $out = $xs->XMLin($in, 
-    SuppressEmpty => '', 
-    ForceArray => [$field, 'dbName'],
-    KeyAttr => [$field, 'dbName'],
-  );
+  my $out = $xs->XMLin($in);
 
   return $out;
 }
 
-# Returns the XML response body.
 sub _call {
   my ($self) = @_;
 
-  # construct the url
   my $url = $self->base;
   if ($self->module eq 'search') {
     $url .= '/search/query=' . $self->query;
@@ -70,26 +61,20 @@ sub _call {
     $url .= '/'. $self->page if $self->page;
   }
 
-  # http get the url.
   my $res = $self->_request($url);
 
-  # return the response body.
   return $res;
 }
 
 sub _get_record {
   my ($self) = @_;
   
-  # fetch the xml response and hashify it.
   my $xml = $self->_call;
   my $hash = $self->_hashify($xml);
     
-  # return a reference to a hash.
   return $hash;
 }
 
-# Public Methods. --------------------------------------------------------------
-
 sub generator {
 
   my ($self) = @_;
